
.installed-overlay-box {
	font-size: 80%;
	background-color: @theme_selected_bg_color;
	border-radius: 4px;
	color: @theme_selected_fg_color;
	text-shadow: 0 1px 0 rgba(0,0,0,0.5);
}

.popular-installed-overlay-box {
	font-size: 80%;
	background-color: @theme_selected_bg_color;
	border-radius: 0;
	color: @theme_selected_fg_color;
	text-shadow: none;
}

.index-title-alignment-software {
	font-weight: bold;
	font-size: 14px;
}

.needs-attention {
        background-image: none;
        background-color: shade(@theme_selected_bg_color, 1.1);
        border-radius: 1px;
}

.screenshot-image, .screenshot-image-thumb {
        background-image: none;
        background-color: shade(@theme_bg_color, 0.9);
}
  .screenshot-image { border-radius: 5px; }
  .screenshot-image-thumb { border-radius: 3px; }

.app-tile-label {
        font-size: 10px;
}

.view.tile {
	padding: 0;
	box-shadow: inset 0 1px @theme_base_color, 0 1px 1px alpha(black,0.4);
	border: 1px solid mix(@theme_base_color,@theme_fg_color,0.3);
	background-image: none;
	background-color: mix(@theme_base_color,@theme_bg_color,0.3);
}

.view.tile:hover {
	background-color: @theme_base_color;
}

.view.tile:active {
	border-color: @theme_selected_bg_color;
	box-shadow: none;
	color: @theme_selected_bg_color;
}

.view.tile:backdrop {
	box-shadow: none;
	border-color: @unfocused_borders;
}

/* The rest of the featured-tile CSS is loaded at runtime in gs-feature-tile.c */
.button.featured-tile {
	all: unset;
	padding: 0;
	border-radius: 0;
	border-width: 1px;
	border-image: none;
	box-shadow: inset 0 0 0 1px alpha(@theme_fg_color,0.3), 0 0 1px alpha(black,0.4);
}

.application-details-infobar.info {
        background-color: #d3d7cf;
        color: @theme_fg_color;
        border-color: darker(#d3d7cf);
        border-style: solid;
        border-width: 1px;
        text-shadow: none;
}

.application-details-infobar.warning {
        background-color: #fcaf3e;
        color: @theme_fg_color;
        border-color: darker(#fcaf3e);
        border-style: solid;
        border-width: 1px;
        text-shadow: none;
}

.application-details-title {
	font-weight: bold;
	font-size: 14px;
}

.application-details-summary {
}

.application-details-description {
}

.error-label {
	text-shadow: none;
}

.folder-label {
	font-size: 9px;
	background-color: #999999;
	border-radius: 4px;
	padding: 4px 8px;
	color: white;
}

.header-label {
	font-size: 11px;
	padding: 6px;
	background-image: none;
	background-color: #babdb6;
	border-color: #000000;
}

.image-list {
	background-color: transparent;
}

GtkBox.star {
	background-color: transparent;
	background-image: none;
}

.button.star {
	-GtkWidget-focus-padding: 0;
	background-color: transparent;
	background-image: none;
	border-image: none;
	border-radius: 0;
	border-width: 0px;
	padding: 0;
	box-shadow: none;
	outline-offset: -1px;
}

.star {
	color: #888a85;
}

.star-user {
	color: @theme_selected_bg_color;
}

.counter-label {
    text-shadow: none;
    color: @theme_selected_fg_color;
    background-color: mix(@theme_selected_bg_color, @theme_selected_fg_color, 0.3);
    font-size: smaller;
    border-radius: 4px;
    padding: 0px 4px;
}

.category-sidebar {
	border-radius: 0;
	border-bottom-width: 0;
	border-top-width: 0;
}

.category-sidebar GtkListBox {
	background-color: @theme_bg_color;
}

.category-sidebar GtkListBoxRow {
	padding-left: 6px;
	animation: none;
	transition: none;
}

.category-sidebar GtkListBoxRow:dir(rtl) {
	padding-right: 6px;
	animation: none;
	transition: none;
}

.category-sidebar GtkListBoxRow:hover {
	background-color: @theme_bg_color;
}

.category-sidebar GtkListBoxRow:selected:hover {
	background-color: @theme_selected_bg_color;
}
